#!/bin/bash

INST_DIR="/opt/assistant"
LOG_FILE=$INST_DIR/log/setup.log
SHORTCUT_PATH=$INST_DIR/scripts/assistant.desktop
USERS_LIST=$(ls -d /home/*/)
PATH_TO_CONF=/.config/user-dirs.dirs
TRUST="/etc/X11/trusted"
CERT_PATH=/etc/assistant/cert/ca-cert-native
PATHS_TO_CERT=(
"/etc/ssl/certs/ca-certificates.crt" 
"/etc/pki/tls/certs/ca-bundle.crt" 
"/etc/pki/ca-trust/extracted/pem/tls-ca-bundle.pem" 
"/usr/share/ca-certificates/ca-bundle.crt" 
"/etc/ssl/certs/ssl-cert-snakeoil.pem" 
"/etc/ca-certificates/extracted/ca-bundle.trust.crt"
"/var/lib/ca-certificates/ca-bundle.pem"
)

. $INST_DIR/scripts/get_version_os.sh

log(){
	date_str=$(date "+%e.%m.%y %T.%3N")
	echo $date_str"        "$1 >> $LOG_FILE
}




#	Созданиее ярлыка на рабочем столе 

create_shortcut(){
	PATH_TO_DESK=$1
	if [[ -d $PATH_TO_DESK	]]; then
		case $2 in 
		"--install" | "-i")
			log "Create desktop shortcut '$PATH_TO_DESK/assistant.desktop'"
			cp -p $SHORTCUT_PATH "$PATH_TO_DESK/" 2>> $LOG_FILE
			if [ $? != 0 ]; then log "Error creating shortcut"; fi
		;;
		"--uninstall" | "-u")
			rm -f "$PATH_TO_DESK/assistant.desktop"
			log "Remove desktop shortcut '$PATH_TO_DESK/assistant.desktop'"
		;;
		*)
			echo "Invalid params: \"$2\" "
			log "Invalid params: \"$2\" "
		;;
		esac
	fi
}

add_shortcut_to_app_list(){
case $1 in
	"--install" | "-i")
		[[ -d /usr/share/applications ]] && cp -p $INST_DIR/scripts/assistant.desktop /usr/share/applications/
		if [ $? == 0 ]; then 
			echo "Added shortcut to application list"
			log "Added shortcut to application list"
		else 
			log "Failed to add shortcut to application list"
		fi
		rm -f $SHORTCUT_PATH
		log "Old shortcut removed from application directory '$SHORTCUT_PATH'"
	;;
	"--uninstall" | "-u")
		rm -f /usr/share/applications/assistant.desktop
		log "Removed shortcut from the application list '/usr/share/applications/assistant.desktop'"
		touch $SHORTCUT_PATH
	;;
	esac
}

shortcut(){
for HOME_USER in ${USERS_LIST[@]}
	do
		DIRS=$HOME_USER$PATH_TO_CONF
		if [[ -f $DIRS ]]; then
			. $DIRS
			log "Get user data from '$DIRS'"
			DESKTOP_NAME=$(basename "$XDG_DESKTOP_DIR")
			create_shortcut "$HOME_USER$DESKTOP_NAME" $1
		fi
	done
add_shortcut_to_app_list $1
}

#	Cоздание ссылки сертификата
make_ca()
{
mkdir -p /etc/assistant/cert/
for cert in ${PATHS_TO_CERT[@]}
	do
		if [ -f $cert ] && [ ! -L $cert ]; then 
			log "'$cert' is found"
			ln -s $cert $CERT_PATH
			log "Created CA-certificate link '$CERT_PATH'"
			return 0;
		fi
	done
	echo "Failed to create CA certificate link for system $ID $VER"
	log "Unsupported version $ID $VER"
	return 1
}

cert() {
case $1 in 
	"--install" | "-i")
		log "Adding CA certificate link"
		[ -L $CERT_PATH ] || ( make_ca && echo "CA certificate installed" )
		if [ $? != 0 ]; then log "Error adding CA certificate link"; else log "CA certificate installed"; fi
	;;
	"--uninstall" | "-u")
		log "Removing CA certificate link"
		[ ! -L $CERT_PATH ] || ( rm -r /etc/assistant && echo "CA certificate deleted" )
		if [ $? != 0 ]; then log "Error removing CA certificate link"; else log "CA certificate deleted" ; fi
	;;
	*)
		echo "Invalid params: '$*'"
		log "Invalid params: '$*'"
	;;
esac
}

#Внесение изменений в файл "/etc/X11/trusted"
trusted(){
if [[ -f $TRUST ]]; then
	case $1 in
	"--install" | "-i")
		sed -ie '/^\/opt\/assistant\/bin\/assistant$/d' $TRUST
		echo -e "/opt/assistant/bin/assistant" >> $TRUST
		sed -ie '/^\/opt\/assistant\/bin\/asts$/d' $TRUST
		echo "/opt/assistant/bin/asts" >> $TRUST
		sed -ie '/^\/opt\/assistant\/bin\/astrct$/d' $TRUST
		echo "/opt/assistant/bin/astrct" >> $TRUST
		echo "Added entries to the file '$TRUST'"
		log "Added entries to the file '$TRUST'"
	;;
	"--uninstall" | "-u")
		sed -ie '/^\/opt\/assistant\/bin\/assistant$/d' $TRUST
		sed -ie '/^\/opt\/assistant\/bin\/asts$/d' $TRUST
		sed -ie '/^\/opt\/assistant\/bin\/astrct$/d' $TRUST
		echo "Deleted entries from the file '$TRUST'"
		log "Deleted entries from the file '$TRUST'"
	;;
	esac

fi
}


if [[ "${BASH_SOURCE[0]}" == "${0}" ]]; then
	echo "Setup Assistant for '$ID $VER'"
	log "Setup Assistant for '$ID $VER'"
	log "Setup daemon"
	$INST_DIR/scripts/daemon.sh $1 | tee -a $LOG_FILE
	log "Daemon setup completed"
	cert $1
	shortcut $1 
	trusted $1
	echo "Assistant setup completed"
	log "Assistant setup completed"
	exit 0
fi
